==> react-atom-video-player-1.29.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { createRef, forwardRef, Suspense, useRef } from 'react';
import PropTypes from 'prop-types';
import useDetectVideoType from './hooks/useDetectVideoType.js';
import useScrollAutoplayEffect from './hooks/useScrollAutoplayEffect.js';
import useVideoPlayer from './hooks/useVideoPlayer.js';
import { AUTOPLAY, AUTOPLAY_DEFAULT_VALUE, AUTOPLAY_OPTIONS, BASE_CLASS, INTERSECTION_OBSERVER_DEFAULT_CONFIGURATION, NO_OP, UNKNOWN } from './settings/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
var AtomVideoPlayer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$autoPlay = _ref.autoPlay,
    autoPlay = _ref$autoPlay === void 0 ? AUTOPLAY_DEFAULT_VALUE : _ref$autoPlay,
    _ref$controls = _ref.controls,
    controls = _ref$controls === void 0 ? true : _ref$controls,
    _ref$fallbackComponen = _ref.fallbackComponent,
    fallbackComponent = _ref$fallbackComponen === void 0 ? null : _ref$fallbackComponen,
    _ref$intersectionObse = _ref.intersectionObserverConfiguration,
    intersectionObserverConfiguration = _ref$intersectionObse === void 0 ? INTERSECTION_OBSERVER_DEFAULT_CONFIGURATION : _ref$intersectionObse,
    _ref$muted = _ref.muted,
    muted = _ref$muted === void 0 ? false : _ref$muted,
    _ref$onLoadVideo = _ref.onLoadVideo,
    onLoadVideo = _ref$onLoadVideo === void 0 ? NO_OP : _ref$onLoadVideo,
    _ref$playsInline = _ref.playsInline,
    playsInline = _ref$playsInline === void 0 ? false : _ref$playsInline,
    _ref$src = _ref.src,
    src = _ref$src === void 0 ? '' : _ref$src,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    title = _ref.title;
  if (forwardedRef === void 0) {
    forwardedRef = /*#__PURE__*/createRef();
  }
  var _useVideoPlayer = useVideoPlayer({
      autoPlay: autoPlay,
      controls: controls,
      muted: muted,
      onLoadVideo: onLoadVideo,
      playsInline: playsInline,
      src: src,
      timeLimit: timeLimit,
      title: title,
      timeOffset: timeOffset
    }),
    Component = _useVideoPlayer[0],
    props = _useVideoPlayer[1];
  var componentRef = useRef(null);
  var autoPlayState = useScrollAutoplayEffect({
    autoPlay: autoPlay,
    intersectionObserverConfiguration: intersectionObserverConfiguration,
    muted: muted,
    ref: componentRef
  });
  return /*#__PURE__*/_jsx("div", {
    ref: componentRef,
    className: BASE_CLASS,
    children: /*#__PURE__*/_jsx(Suspense, {
      fallback: fallbackComponent,
      children: /*#__PURE__*/_jsx(Component, _extends({}, _extends({}, props, {
        autoPlay: autoPlayState,
        ref: forwardedRef
      })))
    })
  });
});
AtomVideoPlayer.displayName = 'AtomVideoPlayer';
export default AtomVideoPlayer;
export { AUTOPLAY, UNKNOWN, useDetectVideoType };

==> react-atom-video-player-1.31.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { createRef, forwardRef, Suspense, useRef } from 'react';
import PropTypes from 'prop-types';
import useDetectVideoType from './hooks/useDetectVideoType.js';
import useScrollAutoplayEffect from './hooks/useScrollAutoplayEffect.js';
import useVideoPlayer from './hooks/useVideoPlayer.js';
import { AUTOPLAY, AUTOPLAY_DEFAULT_VALUE, AUTOPLAY_OPTIONS, BASE_CLASS, INTERSECTION_OBSERVER_DEFAULT_CONFIGURATION, NO_OP, UNKNOWN } from './settings/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
var AtomVideoPlayer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$autoPlay = _ref.autoPlay,
    autoPlay = _ref$autoPlay === void 0 ? AUTOPLAY_DEFAULT_VALUE : _ref$autoPlay,
    _ref$controls = _ref.controls,
    controls = _ref$controls === void 0 ? true : _ref$controls,
    _ref$fallbackComponen = _ref.fallbackComponent,
    fallbackComponent = _ref$fallbackComponen === void 0 ? null : _ref$fallbackComponen,
    _ref$fallbackWhileNot = _ref.fallbackWhileNotOnViewport,
    fallbackWhileNotOnViewport = _ref$fallbackWhileNot === void 0 ? false : _ref$fallbackWhileNot,
    _ref$intersectionObse = _ref.intersectionObserverConfiguration,
    intersectionObserverConfiguration = _ref$intersectionObse === void 0 ? INTERSECTION_OBSERVER_DEFAULT_CONFIGURATION : _ref$intersectionObse,
    _ref$muted = _ref.muted,
    muted = _ref$muted === void 0 ? false : _ref$muted,
    _ref$onLoadVideo = _ref.onLoadVideo,
    onLoadVideo = _ref$onLoadVideo === void 0 ? NO_OP : _ref$onLoadVideo,
    _ref$playsInline = _ref.playsInline,
    playsInline = _ref$playsInline === void 0 ? false : _ref$playsInline,
    _ref$src = _ref.src,
    src = _ref$src === void 0 ? '' : _ref$src,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    title = _ref.title;
  if (forwardedRef === void 0) {
    forwardedRef = /*#__PURE__*/createRef();
  }
  var _useVideoPlayer = useVideoPlayer({
      autoPlay: autoPlay,
      controls: controls,
      muted: muted,
      onLoadVideo: onLoadVideo,
      playsInline: playsInline,
      src: src,
      timeLimit: timeLimit,
      title: title,
      timeOffset: timeOffset
    }),
    Component = _useVideoPlayer[0],
    props = _useVideoPlayer[1];
  var componentRef = useRef(null);
  var autoPlayState = useScrollAutoplayEffect({
    autoPlay: autoPlay,
    intersectionObserverConfiguration: intersectionObserverConfiguration,
    muted: muted,
    ref: componentRef
  });
  var needsToRenderFallbackComponent = fallbackWhileNotOnViewport === true && autoPlay === AUTOPLAY.ON_VIEWPORT && !autoPlayState;
  return /*#__PURE__*/_jsx("div", {
    ref: componentRef,
    className: BASE_CLASS,
    children: needsToRenderFallbackComponent ? fallbackComponent : /*#__PURE__*/_jsx(Suspense, {
      fallback: fallbackComponent,
      children: /*#__PURE__*/_jsx(Component, _extends({}, _extends({}, props, {
        autoPlay: autoPlayState,
        ref: forwardedRef
      })))
    })
  });
});
AtomVideoPlayer.displayName = 'AtomVideoPlayer';
export default AtomVideoPlayer;
export { AUTOPLAY, UNKNOWN, useDetectVideoType };
